==> fl_camera-1.0.0.tar.gz: android/src/main/kotlin/fl/camera/FlCameraMethodCall.kt <==
package fl.camera

import androidx.camera.core.ImageAnalysis
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel

open class FlCameraMethodCall(
    private var activityPlugin: ActivityPluginBinding,
    private var plugin: FlutterPlugin.FlutterPluginBinding
) :
    MethodChannel.MethodCallHandler {
    var flCameraEvent: FlCameraEvent? = null
    var flCamera: FlCameraX? = null

    override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
        when (call.method) {
            "initCamera" -> {
                if (flCamera == null && flCameraEvent != null) {
                    flCamera =
                        FlCameraX(activityPlugin.activity, plugin.textureRegistry, flCameraEvent!!)
                }
                result.success(flCamera != null)
            }
            "startPreview" -> startPreview(null, call, result)
            "setFlashMode" -> {
                val status = call.arguments as Boolean
                flCamera?.setFlashMode(status)
                result.success(flCamera != null)
            }
            "disposeCamera" -> {
                if (flCamera != null) {
                    flCamera!!.dispose()
                    flCamera = null
                }
                result.success(true)
            }
            "startEvent" -> {
                initEvent()
                result.success(flCameraEvent != null)
            }
            "sendEvent" -> {
                flCameraEvent?.sendEvent(call.arguments)
                result.success(flCameraEvent != null)
            }
            "stopEvent" -> {
                if (flCameraEvent != null) {
                    flCameraEvent?.dispose()
                    flCameraEvent = null
                }
                result.success(flCameraEvent == null)
            }
            else -> result.notImplemented()
        }
    }

    private fun initEvent() {
        if (flCameraEvent == null) {
            flCameraEvent = FlCameraEvent(plugin.binaryMessenger)
        }
    }

    fun startPreview(
        imageAnalyzer: ImageAnalysis.Analyzer?,
        call: MethodCall,
        result: MethodChannel.Result
    ) {

        var useBackCamera = call.argument<Boolean>("useBackCamera")
        val zoom = call.argument<Int>("zoom")
        if (useBackCamera == null) useBackCamera = true
        flCamera?.initCameraX(zoom!!, useBackCamera, result, imageAnalyzer)
    }
}

==> fl_camera-1.3.0.tar.gz: android/src/main/kotlin/fl/camera/FlCameraMethodCall.kt <==
package fl.camera

import android.app.Activity
import androidx.camera.core.ImageAnalysis
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel

open class FlCameraMethodCall(
    private var activity: Activity,
    private var plugin: FlutterPlugin.FlutterPluginBinding
) :
    MethodChannel.MethodCallHandler {
    var flCameraEvent: FlCameraEvent? = null
    private var flCamera: FlCameraX? = null

    override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
        when (call.method) {
            "availableCameras" -> {
                result.success(CameraTools.getAvailableCameras(activity))
            }
            "initCamera" -> {
                if (flCamera == null && flCameraEvent != null) {
                    flCamera =
                        FlCameraX(activity, plugin.textureRegistry, flCameraEvent!!)
                }
                result.success(flCamera != null)
            }
            "startPreview" -> startPreview(null, call, result)
            "setFlashMode" -> {
                flCamera?.setFlashMode(call.arguments as Boolean)
                result.success(flCamera != null)
            }
            "setZoomRatio" -> {
                flCamera?.setZoomRatio((call.arguments as Double).toFloat())
                result.success(flCamera != null)
            }
            "disposeCamera" -> {
                if (flCamera != null) {
                    flCamera!!.dispose()
                    flCamera = null
                }
                result.success(true)
            }
            "startEvent" -> {
                initEvent()
                result.success(flCameraEvent != null)
            }
            "sendEvent" -> {
                flCameraEvent?.sendEvent(call.arguments)
                result.success(flCameraEvent != null)
            }
            "stopEvent" -> {
                if (flCameraEvent != null) {
                    flCameraEvent?.dispose()
                    flCameraEvent = null
                }
                result.success(flCameraEvent == null)
            }
            else -> result.notImplemented()
        }
    }

    private fun initEvent() {
        if (flCameraEvent == null) {
            flCameraEvent = FlCameraEvent(plugin.binaryMessenger)
        }
    }

    open fun startPreview(
        imageAnalyzer: ImageAnalysis.Analyzer?,
        call: MethodCall,
        result: MethodChannel.Result
    ) {
        val resolution = call.argument<String>("resolution")
        val cameraId = call.argument<String>("cameraId")
        val previewSize = CameraTools.computeBestPreviewSize(cameraId!!, resolution!!)
        val cameraSelector = CameraTools.getCameraSelector(cameraId)
        flCamera?.initCameraX(previewSize, cameraSelector, result, imageAnalyzer)
    }
}
